@@ -18,9 +18,11 @@
 
 (library (scss properties)
   (export validate-property 
-	  property-hash-table
+	  get-prop-entry
+	  get-default-prop-value
 	  color-table
-
+	  ident?
+	  
 	  specify
 	  
 	  css-property:default
@@ -28,7 +30,7 @@
 
   (import (rnrs)
 	  (scss common)
-	  (only (srfi :1) drop)
+	  (only (srfi :1) drop last-pair list-index)
 	  (srfi :2)
 	  (srfi :13)
 	  (srfi :14))
@@ -557,6 +559,11 @@
 		properties)
       pht))
   
+  (define (get-prop-entry prop) (hashtable-ref property-hash-table prop #f))
+  (define (get-default-prop-value prop)
+    (let ((entry (get-prop-entry prop)))
+      (and entry (css-property:default entry))))
+
   ;; This function is a bit complicated.  The general idea is that for certain
   ;; properties, if they're not explicitly defined in the matched selector 
   ;; block, you can derive their value by looking at a more general property 
