@@ -69,3 +69,13 @@
        #f #f '(css ((.one .two .three) (color "green"))))
       '((p (class . "three")))
       '((color . "green")))
+
+(test (scss:make-cascade
+       #f #f '(css (p (! (color "green"))) (p (color "red"))))
+      '((p))
+      '((color . "green") (color . "red")))
+
+(test (scss:make-cascade
+       #f #f '(css (p (! (color "green"))) ((p (id "id1")) (color "red"))))
+      '((p (id . "id1")))
+      '((color . "green") (color . "red")))
